@@ -1,4 +1,4 @@
-#  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
+#  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
 #  dedicated to making software imaging solutions freely available.
 #
 #  You may not use this file except in compliance with the License.  You may
@@ -96,6 +96,7 @@ sub testCompositeCompare {
       goto COMPARE_RUNTIME_ERROR;
     }
 
+  $background->Clamp();
   $background->set(depth=>8);
 #  if ("$filter" eq "Atop") {
 #    $background->write(filename=>"$refimage_name", compression=>'None');
@@ -181,11 +182,11 @@ sub testRead {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -222,7 +223,7 @@ sub testRead {
        	print "Image: $infile, signatures do not match.\n";
       	print "     Expected: $ref_signature\n";
       	print "     Computed: $signature\n";
-        print "     Depth:    ", QuantumDepth, "\n";
+        print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
         ++$failure;
         $image->Display();
       }
@@ -260,7 +261,7 @@ sub testRead {
               print "Image: $infile, signatures do not match.\n";
               print "     Expected: $ref_signature\n";
               print "     Computed: $signature\n";
-              print "     Depth:    ", QuantumDepth, "\n";
+              print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
               #$image->Display();
               ++$failure;
             }
@@ -330,6 +331,7 @@ sub testReadCompare {
       goto COMPARE_RUNTIME_ERROR;
     }
 
+  $srcimage->Clamp();
   $srcimage->set(depth=>8);
 
   # FIXME: The following statement should not be needed.
@@ -418,11 +420,11 @@ sub testReadSized {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -438,8 +440,8 @@ sub testReadSized {
   warn "$status" if "$status";
 
   # If depth is not zero, then set it
-  if ( QuantumDepth != 0 ) {
-    $status=$image->SetAttribute(depth=>QuantumDepth);
+  if ( Image::Magick->new()->QuantumDepth != 0 ) {
+    $status=$image->SetAttribute(depth=>Image::Magick->new()->QuantumDepth);
     warn "$status" if "$status";
   }
 
@@ -454,7 +456,7 @@ sub testReadSized {
       	print "Image: $infile, signatures do not match.\n";
       	print "     Expected: $ref_signature\n";
       	print "     Computed: $signature\n";
-        print "     Depth:    ", QuantumDepth, "\n";
+        print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
         print "not ok $test\n";
         #$image->Display();
       } else {
@@ -492,11 +494,11 @@ sub testReadWrite {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -541,7 +543,7 @@ sub testReadWrite {
           print "Image: $infile, signatures do not match.\n";
           print "     Expected: $ref_signature\n";
           print "     Computed: $signature\n";
-          print "     Depth:    ", QuantumDepth, "\n";
+          print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
           print "not ok $test\n";
           $image->Display();
         } else {
@@ -639,6 +641,7 @@ sub testReadWriteCompare {
   # Compare output file with reference image
   #
 
+  $image->Clamp();
   $image->set(depth=>8);
 
   # FIXME: The following statement should not be needed.
@@ -782,11 +785,11 @@ sub testReadWriteSized {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -853,7 +856,7 @@ sub testReadWriteSized {
           print "Image: $infile, signatures do not match.\n";
           print "     Expected: $ref_signature\n";
           print "     Computed: $signature\n";
-          print "     Depth:    ", QuantumDepth, "\n";
+          print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
           print "not ok $test\n";
           #$image->Display();
         } else {
@@ -966,11 +969,11 @@ sub testMontage {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -1039,7 +1042,7 @@ sub testMontage {
         print "Test $test, signatures do not match.\n";
       	print "     Expected: $ref_signature\n";
       	print "     Computed: $signature\n";
-        print "     Depth:    ", QuantumDepth, "\n";
+        print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
         $status = $montage->Write("test_${test}_out.miff");
         warn "Write: $status" if "$status";
           
@@ -1097,11 +1100,11 @@ sub testFilterSignature {
       $ref_32 = $ref_16;
     }
 
-  if (QuantumDepth == 32)
+  if (Image::Magick->new()->QuantumDepth == 32)
     {
       $ref_signature=$ref_32;
     }
-  elsif (QuantumDepth == 16)
+  elsif (Image::Magick->new()->QuantumDepth == 16)
     {
       $ref_signature=$ref_16;
     }
@@ -1126,7 +1129,7 @@ sub testFilterSignature {
       print "Test $test, signatures do not match.\n";
       print "     Expected: $ref_signature\n";
       print "     Computed: $signature\n";
-      print "     Depth:    ", QuantumDepth, "\n";
+      print "     Depth:    ", Image::Magick->new()->QuantumDepth, "\n";
       #$image->Display();
       print "not ok $test\n";
     } else {
@@ -1187,6 +1190,7 @@ sub testFilterCompare {
       goto COMPARE_RUNTIME_ERROR;
     }
 
+  $srcimage->Clamp();
   $srcimage->set(depth=>8);
 #  if ("$filter" eq "Shear") {
 #    $srcimage->Display();
